Knowledge Embedding Kit
===

[![PyPI version fury.io](https://badge.fury.io/py/kgekit.svg)](https://pypi.python.org/project/kgekit/)
[![PyPI license](https://img.shields.io/pypi/l/kgekit.svg)](https://pypi.python.org/project/kgekit/)
[![Build Status](https://travis-ci.com/fantasticfears/kgekit.svg?branch=master)](https://travis-ci.com/fantasticfears/kgekit)

This library provides helpful functions and sampling for KGE learning.
The data processing part is strictly research-oriented.

Requirements:

- C++17 compilers

# Features

- Eficient data representation in C++ and interoperability in Python by pybind11.
- Triple data IO, processing and extraction.
- Various sampling methods.
